==> festival_1.2.1.orig.tar.gz: festival/testsuite/data/voices.scm <==
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                       ;;
;;;                Centre for Speech Technology Research                  ;;
;;;                     University of Edinburgh, UK                       ;;
;;;                       Copyright (c) 1996,1997                         ;;
;;;                        All Rights Reserved.                           ;;
;;;                                                                       ;;
;;;  Permission to use, copy, modify, distribute this software and its    ;;
;;;  documentation for research, educational and individual use only, is  ;;
;;;  hereby granted without fee, subject to the following conditions:     ;;
;;;   1. The code must retain the above copyright notice, this list of    ;;
;;;      conditions and the following disclaimer.                         ;;
;;;   2. Any modifications must be clearly marked as such.                ;;
;;;   3. Original authors' names are not deleted.                         ;;
;;;  This software may not be used for commercial purposes without        ;;
;;;  specific prior written permission from the authors.                  ;;
;;;                                                                       ;;
;;;  THE UNIVERSITY OF EDINBURGH AND THE CONTRIBUTORS TO THIS WORK        ;;
;;;  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      ;;
;;;  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   ;;
;;;  SHALL THE UNIVERSITY OF EDINBURGH NOR THE CONTRIBUTORS BE LIABLE     ;;
;;;  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    ;;
;;;  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   ;;
;;;  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          ;;
;;;  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       ;;
;;;  THIS SOFTWARE.                                                       ;;
;;;                                                                       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Test some voice switching


(voice_rab_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/rab1.wav")
(voice_don_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/don1.wav")
(voice_kd_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/kd1.wav")

(voice_rab_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/rab2.wav")
(voice_don_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/don2.wav")
(voice_kd_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/kd2.wav")

==> festival-1.4.1.tar.gz: festival/testsuite/data/voices.scm <==
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                       ;;
;;;                Centre for Speech Technology Research                  ;;
;;;                     University of Edinburgh, UK                       ;;
;;;                       Copyright (c) 1996,1997                         ;;
;;;                        All Rights Reserved.                           ;;
;;;                                                                       ;;
;;;  Permission is hereby granted, free of charge, to use and distribute  ;;
;;;  this software and its documentation without restriction, including   ;;
;;;  without limitation the rights to use, copy, modify, merge, publish,  ;;
;;;  distribute, sublicense, and/or sell copies of this work, and to      ;;
;;;  permit persons to whom this work is furnished to do so, subject to   ;;
;;;  the following conditions:                                            ;;
;;;   1. The code must retain the above copyright notice, this list of    ;;
;;;      conditions and the following disclaimer.                         ;;
;;;   2. Any modifications must be clearly marked as such.                ;;
;;;   3. Original authors' names are not deleted.                         ;;
;;;   4. The authors' names are not used to endorse or promote products   ;;
;;;      derived from this software without specific prior written        ;;
;;;      permission.                                                      ;;
;;;                                                                       ;;
;;;  THE UNIVERSITY OF EDINBURGH AND THE CONTRIBUTORS TO THIS WORK        ;;
;;;  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      ;;
;;;  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   ;;
;;;  SHALL THE UNIVERSITY OF EDINBURGH NOR THE CONTRIBUTORS BE LIABLE     ;;
;;;  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    ;;
;;;  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   ;;
;;;  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          ;;
;;;  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       ;;
;;;  THIS SOFTWARE.                                                       ;;
;;;                                                                       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Test some voice switching


(voice_rab_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/rab1.wav")
(voice_don_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/don1.wav")
(voice_ked_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/ked1.wav")

(voice_rab_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/rab2.wav")
(voice_don_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/don2.wav")
(voice_ked_diphone)
(set! utt1 (Utterance Text "The date was July 24th 1997."))
(utt.synth utt1)
(utt.save.wave utt1 "tmp/ked2.wav")
